package com.yskj.acdr.common.verify;

import cn.hutool.core.util.StrUtil;
import lombok.Getter;
import org.springframework.stereotype.Component;

@Getter
@Component
public class UserNameValidator {

    private String errorString = "用户名不合法";

    // 非法词语列表
    private final String[] ILLEGAL_WORDS = {"admin", "root", "illegal"};

    @Override
    public String toString() {
        return errorString;
    }

    public boolean valid(String userName) {
        // 用户名不能为空
        if (StrUtil.isBlank(userName)) {
            errorString = "用户名不能为空";
            System.out.println(errorString);
            return false;
        }

        // 用户名长度不能大于6
        if (userName.length() > 6) {
            errorString = "用户名长度大于6";
            System.out.println(errorString);
            return false;
        }

        // 用户名不能以特殊字符开头（仅允许字母或数字开头）
        if (!Character.isLetterOrDigit(userName.charAt(0))) {
            errorString = "用户名不能以特殊字符开头";
            System.out.println(errorString);
            return false;
        }

        // 用户名不能全是数字
        if (userName.matches("\\d+")) {
            errorString = "用户名不能全是数字";
            System.out.println(errorString);
            return false;
        }

        // 用户名不能包含违法词语
        for (String word : ILLEGAL_WORDS) {
            if (userName.toLowerCase().contains(word)) {
                errorString = "用户名包含违法词语: " + word;
                System.out.println(errorString);
                return false;
            }
        }

        // 所有条件都符合，验证通过
        return true;
    }
}
