package com.yskj.acdr.master.ad.controller;

import com.yskj.acdr.common.response.GlobalResponse;
import com.yskj.acdr.master.ad.entity.Ad;
import com.yskj.acdr.master.ad.service.IAdService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jakarta.validation.groups.Default;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 推广表 前端控制器
 * </p>
 *
 * @author 林河
 * @since 2024-09-12
 */
@Api(tags = "推广表")
@RestController
@RequestMapping("/ad")
public class AdController {

    @Autowired
    private IAdService service;

    @ApiOperation(value = "推广表分页列表", response = Ad.class)
    @PostMapping(value = "/page")
    public GlobalResponse<Ad> list(GlobalResponse<Ad> page) {
        return service.lambdaQuery().page(page);
    }

    @ApiOperation(value = "推广表详情", response = Ad.class)
    @GetMapping(value = "/info/{id}")
    public GlobalResponse<Ad> info(@Validated({GetMapping.class}) @PathVariable Long id) {
        Ad ad = service.getById(id);
        return GlobalResponse.success(ad);
    }

    @ApiOperation(value = "推广表新增")
    @PostMapping(value = "/add")
    public GlobalResponse<Ad> add(@Validated({PostMapping.class, Default.class}) @RequestBody Ad param) {
        service.save(param);
        return GlobalResponse.success("推广表新增成功！");
    }

    @ApiOperation(value = "推广表修改")
    @PostMapping(value = "/modify")
    public GlobalResponse<Ad> modify(@Validated({PutMapping.class, Default.class}) @RequestBody Ad param) {
        service.updateById(param);
        return GlobalResponse.success("推广表修改成功！");
    }

    @ApiOperation(value = "推广表删除(单个条目)")
    @GetMapping(value = "/remove/{id}")
    public GlobalResponse<Ad> remove(@Validated({DeleteMapping.class}) @PathVariable Long id) {
        service.removeById(id);
        return GlobalResponse.success("推广表删除(单个条目)！");
    }

    @ApiOperation(value = "推广表删除(多个条目)")
    @PostMapping(value = "/removes")
    public GlobalResponse<Ad> removes(@RequestBody List<Long> ids) {
        service.removeBatchByIds(ids);
        return GlobalResponse.success("推广表删除(多个条目)！");
    }
}
