package com.yskj.acdr.master.address.controller;

import com.alibaba.fastjson2.JSONObject;
import com.yskj.acdr.common.response.GlobalResponse;
import com.yskj.acdr.master.address.service.ServiceAddressService;
import jakarta.annotation.Resource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/map")
public class ServiceAddressController {

    private static final Logger log = LoggerFactory.getLogger(ServiceAddressController.class);
    @Resource
    private ServiceAddressService addressService;

    /**
     * @param longitude 经度
     * @param latitude  纬度
     * @return {
     * "addressComponent": {
     * "city": "深圳市",
     * "province": "广东省",
     * "adcode": "440304",
     * "district": "福田区",
     * "towncode": "440304008000",
     * "streetNumber": {
     * "number": "218号",
     * "location": "114.059260,22.542982",
     * "direction": "西",
     * "distance": "33.663",
     * "street": "福中路"
     * },
     * "country": "中国",
     * "township": "莲花街道",
     * "businessAreas": [
     * []
     * ],
     * "building": {
     * "name": [],
     * "type": []
     * },
     * "neighborhood": {
     * "name": [],
     * "type": []
     * },
     * "citycode": "0755"
     * },
     * "formatted_address": "广东省深圳市福田区莲花街道福中三路深圳市民中心"
     * }
     */
    @GetMapping("/detail")
    public GlobalResponse<JSONObject> mapDetail(double longitude, double latitude) {
        try {
            return GlobalResponse.success(addressService.getReverseGeocoding(longitude, latitude));
        } catch (Exception e) {
            log.error(e.getMessage());
            return GlobalResponse.failure("获取地址失败！");
        }
    }



}
