package com.yskj.acdr.master.chat.controller;

import com.yskj.acdr.master.chat.entity.ChatMessage;
import com.yskj.acdr.master.chat.service.ChatMessageService;
import com.yskj.acdr.common.response.GlobalResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jakarta.annotation.Resource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import jakarta.validation.groups.Default;
import org.springframework.validation.annotation.Validated;

import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author 林河
 * @since 2024-09-11
 */
@Api(tags = "通信模块控制器")
@RestController
@RequestMapping("/chatMessage")
public class ChatMessageController {

        @Resource
        private ChatMessageService service;

        @ApiOperation(value = "分页列表", response = ChatMessage.class)
        @PostMapping(value = "/page")
        public  GlobalResponse<ChatMessage> list(GlobalResponse<ChatMessage> page) {
            return service.lambdaQuery().page(page);
        }

        @ApiOperation(value = "详情", response = ChatMessage.class)
        @GetMapping(value = "/info/{id}")
        public  GlobalResponse<ChatMessage> info(@Validated({GetMapping.class}) @PathVariable Long id) {
            ChatMessage chatMessage = service.getById(id);
            return GlobalResponse.success(chatMessage);
        }

        @ApiOperation(value = "新增")
        @PostMapping(value = "/add")
        public  GlobalResponse<ChatMessage> add(@Validated({PostMapping.class, Default.class}) @RequestBody ChatMessage param) {
            service.save(param);
            return GlobalResponse.success("新增成功！");
        }

        @ApiOperation(value = "修改")
        @PostMapping(value = "/modify")
        public  GlobalResponse<ChatMessage> modify(@Validated({PutMapping.class, Default.class}) @RequestBody ChatMessage param) {
            service.updateById(param);
            return GlobalResponse.success("修改成功！");
        }

        @ApiOperation(value = "删除(单个条目)")
        @GetMapping(value = "/remove/{id}")
        public  GlobalResponse<ChatMessage> remove(@Validated({DeleteMapping.class}) @PathVariable Long id) {
            service.removeById(id);
            return GlobalResponse.success("删除(单个条目)！");
        }

        @ApiOperation(value = "删除(多个条目)")
        @PostMapping(value = "/removes")
        public  GlobalResponse<ChatMessage> removes(@RequestBody List<Long> ids) {
            service.removeBatchByIds(ids);
            return GlobalResponse.success("删除(多个条目)！");
        }
}
