package com.yskj.acdr.master.personal.controller;

import cn.hutool.core.map.MapUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.yskj.acdr.common.response.GlobalResponse;
import com.yskj.acdr.master.address.service.ServiceAddressService;
import com.yskj.acdr.master.order.entity.Order;
import com.yskj.acdr.master.order.orderenum.OrderState;
import com.yskj.acdr.master.order.service.OrderService;
import com.yskj.acdr.master.personal.entity.PersonalService;
import com.yskj.acdr.master.personal.service.PersonalServiceService;
import com.yskj.acdr.master.pet.entity.PetInfo;
import com.yskj.acdr.master.pet.entity.PetSpecialistCertificate;
import com.yskj.acdr.master.pet.service.PetInfoService;
import com.yskj.acdr.master.pet.service.PetSpecialistCertificateService;
import com.yskj.acdr.master.user.entity.Users;
import com.yskj.acdr.master.user.service.UsersService;
import io.swagger.annotations.*;
import jakarta.annotation.Resource;
import jakarta.validation.groups.Default;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author 林河
 * @since 2024-08-08
 */
@Api(tags = "核心模块个人服务")
@RestController
@RequestMapping("/personal-service")
@Validated
@Slf4j
public class PersonalServiceController {

    @Resource
    private PersonalServiceService service;

    @Resource
    private UsersService usersService;

    @Resource
    private PetInfoService petInfoService;

    @Resource
    private ServiceAddressService mapService;

    @Resource
    private PetSpecialistCertificateService pscs;

    @Resource
    private OrderService orderService;


    @PostMapping("/push")
    public GlobalResponse<Boolean> push(
            @RequestBody
            @Validated({PostMapping.class, Default.class})
            PersonalService ps) {

        return GlobalResponse.success(service.save(ps));
    }

    @PostMapping("/update")
    public GlobalResponse<Boolean> update(
            @RequestBody
            @Validated({PutMapping.class, Default.class})
            PersonalService ps) {
        return GlobalResponse.success(service.updateById(ps));
    }

    @PostMapping("/delete")
    public GlobalResponse<Boolean> delete(
            @RequestBody
            @Validated({DeleteMapping.class})
            PersonalService ps) {
        return GlobalResponse.success(service.removeById(ps));
    }

    @PostMapping("/get")
    public GlobalResponse<PersonalService> get(
            @RequestBody
            @Validated({GetMapping.class})
            PersonalService ps) {
        return GlobalResponse.success(service.getById(ps));
    }

    @PostMapping("/list")
    public GlobalResponse<PersonalService> list(
            @RequestBody GlobalResponse<PersonalService> page,
            @RequestParam(required = false) Double minLatitude,
            @RequestParam(required = false) Double maxLatitude,
            @RequestParam(required = false) Double minLongitude,
            @RequestParam(required = false) Double maxLongitude,
            @RequestParam(required = false) String sortField,
            @RequestParam(required = false) String sortOrder) {

        PersonalService condition = page.getData(); // 获取查询条件

        LambdaQueryChainWrapper<PersonalService> queryWrapper = service.lambdaQuery();

        if (condition != null) {
            queryWrapper.eq(condition.getId() != null, PersonalService::getId, condition.getId())
                    .like(StringUtils.isNotBlank(condition.getServiceName()), PersonalService::getServiceName, condition.getServiceName())
                    .eq(StringUtils.isNotBlank(condition.getUrl()), PersonalService::getUrl, condition.getUrl())
                    .like(StringUtils.isNotBlank(condition.getServiceHost()), PersonalService::getServiceHost, condition.getServiceHost())
                    .like(StringUtils.isNotBlank(condition.getDescription()), PersonalService::getDescription, condition.getDescription())
                    .eq(StringUtils.isNotBlank(condition.getType()), PersonalService::getType, condition.getType())
                    .eq(condition.getState() != 0, PersonalService::getState, condition.getState())
                    .ge(condition.getPrice() != null, PersonalService::getPrice, condition.getPrice())
                    .eq(condition.getUserId() != null, PersonalService::getUserId, condition.getUserId())
                    .ge(condition.getCreateTime() != null, PersonalService::getCreateTime, condition.getCreateTime())
                    .le(condition.getUpdateTime() != null, PersonalService::getUpdateTime, condition.getUpdateTime())
                    .like(StringUtils.isNotBlank(condition.getAddress()), PersonalService::getAddress, condition.getAddress());
        }

        // 添加经度和纬度范围的条件
        if (minLatitude != null && maxLatitude != null) {
            queryWrapper.between(PersonalService::getLatitude, minLatitude, maxLatitude);
        }
        if (minLongitude != null && maxLongitude != null) {
            queryWrapper.between(PersonalService::getLongitude, minLongitude, maxLongitude);
        }

        // 根据sortField和sortOrder进行排序
        if ("price".equals(sortField)) {
            queryWrapper.orderBy(true, "asc".equals(sortOrder), PersonalService::getPrice);
        } else if ("createTime".equals(sortField)) {
            queryWrapper.orderBy(true, "desc".equals(sortOrder), PersonalService::getCreateTime);
        }

        // 分页查询
        GlobalResponse<PersonalService> resultPage = queryWrapper.page(page);

        return resultPage;
    }


    /**
     * @param id 查询服务id
     * @author linghe
     * 展示宠物个人服务详细信息
     * 返回如下数据：
     *        // 将这些数据都打散装配到Map当中
     *         var map = MapUtil.<String, Object>builder()
     *                 .put("serviceId", p.getId())
     *                 .put("serviceName", p.getServiceName())
     *                 .put("bgUrl", p.getUrl())
     *                 .put("description", p.getDescription())
     *                 .put("serviceType", p.getType())
     *                 .put("latitude", p.getLatitude())
     *                 .put("longitude", p.getLongitude())
     *                 .put("address", p.getAddress())
     *                 .put("serviceState", p.getState())
     *                 .put("createTime", p.getCreateTime())
     *                 .put("updateTime", p.getUpdateTime())
     *                 .put("price", p.getPrice())
     *                 .put("serviceUserId", p.getUserId()) // 服务者ID
     *                 .put("userName", user.getNickname())
     *                 .put("userAvatar", user.getAvatar())
     *                 .put("pets", pets)
     *                 // 添加认证时间
     *                 .put("certificationTime", calculateTimeDifference(LocalDateTime.now(), psc.getCreateTime()))
     *                 .put("serviceNumber", psc.getServiceNumber())
     *                 .put("comments", comments)
     *                 .map();
     */
    @GetMapping("/service/{id}")
    public GlobalResponse<Map<String, Object>> personalDetail(@PathVariable Long id) {
        PersonalService p = service.getById(id);
        Long userId = p.getUserId();
        Users user = usersService.getById(userId);

        // 获取指定用户的宠物信息
        List<PetInfo> list = petInfoService.lambdaQuery()
                .eq(PetInfo::getUserId, userId)
                .list();

        // 获取宠物信息
        var pets = list.stream()
                .map(petInfo -> Map.<String, Object>of("name", petInfo.getName(),
                        "id", petInfo.getId(),
                        "sex", petInfo.getSex(),
                        "profileUrl", petInfo.getProfileUrl()))
                .toList();

        // 获取该宠托师其他信息（服务次数、认证年龄）
        PetSpecialistCertificate psc = pscs.getOne(new LambdaQueryWrapper<PetSpecialistCertificate>()
                .eq(PetSpecialistCertificate::getUserId, userId)
                // 小于过期时间
                .gt(PetSpecialistCertificate::getExpiredTime, LocalDateTime.now()));
        if (psc == null) {
            return GlobalResponse.failure("该用户没有宠物师证书,或者宠物师证书被吊销！");
        }

        // 获取该宠托师以往的订单评论信息, 只获取历史数据的前一条
        // 获取服务次数
        long commitNums = orderService.count(new LambdaQueryWrapper<Order>()
                .eq(Order::getPersonalServiceUserId, userId)
                        .eq(Order::getState, OrderState.EVALUATED)
                .isNotNull(Order::getFeedback)
                .isNotNull(Order::getStar));

        // 获取之后获取该用户的评论信息
        Order commentsOrder = null;
        if(commitNums > 0) {
            commentsOrder = orderService.lambdaQuery()
                    .eq(Order::getPersonalServiceUserId, userId)
                    .eq(Order::getState, OrderState.EVALUATED)
                    .isNotNull(Order::getFeedback)
                    .isNotNull(Order::getStar)
                    .orderByDesc(Order::getStar)
                    .orderByDesc(Order::getCreateTime)
                    .last("LIMIT 1")
                    .one();
        }

        Map<String, Object> comments = null;
        if (commentsOrder != null) {
            comments = new HashMap<>();
            Users users = usersService.getById(commentsOrder.getUserId());
            comments.put("star", commentsOrder.getStar());
            comments.put("comment", commentsOrder.getFeedback());
            comments.put("commentNum", commitNums);
            comments.put("userName", users.getNickname());
            comments.put("userAvatar", users.getAvatar());
        }


        // 将这些数据都打散装配到Map当中
        var map = MapUtil.<String, Object>builder()
                .put("serviceId", p.getId())
                .put("serviceName", p.getServiceName())
                .put("bgUrl", p.getUrl())
                .put("description", p.getDescription())
                .put("serviceType", p.getType())
                .put("latitude", p.getLatitude())
                .put("longitude", p.getLongitude())
                .put("address", p.getAddress())
                .put("serviceState", p.getState())
                .put("createTime", p.getCreateTime())
                .put("updateTime", p.getUpdateTime())
                .put("price", p.getPrice())
                .put("serviceUserId", p.getUserId()) // 服务者ID
                .put("userName", user.getNickname())
                .put("userAvatar", user.getAvatar())
                .put("pets", pets)
                // 添加认证时间
                .put("certificationTime", calculateTimeDifference(LocalDateTime.now(), psc.getCreateTime()))
                .put("serviceNumber", psc.getServiceNumber())
                .put("comments", comments)
                .map();

        return GlobalResponse.success(map);
    }

    public static String calculateTimeDifference(LocalDateTime startDate, LocalDateTime endDate) {
        // 计算年差
        long years = ChronoUnit.YEARS.between(startDate, endDate);
        LocalDateTime tempDateTime = startDate.plusYears(years);

        // 计算月差
        long months = ChronoUnit.MONTHS.between(tempDateTime, endDate);
        tempDateTime = tempDateTime.plusMonths(months);

        // 计算天差
        long days = ChronoUnit.DAYS.between(tempDateTime, endDate);

        // 如果天数小于一个月，按一个月计算
        if (days >= 0 && days < 30) {
            months++;
        }

        if (years == 0) {
            return months + "个月";
        }

        // 返回 xx年xx月 格式
        return years + "年" + months + "个月";
    }

    /**
     * 根据用户的位置获取附近服务的位置。
     *
     * @param page          分页信息封装对象，包含分页参数和返回结果数据
     * @param latitude      用户当前位置的纬度（必填）
     * @param longitude     用户当前位置的经度（必填）
     * @param serviceName   服务名称（可选），用于根据服务名称进行模糊查询
     * @param minPrice      最低价格（可选），用于过滤价格不低于该值的服务
     * @param maxPrice      最高价格（可选），用于过滤价格不高于该值的服务
     * @param priceOrder    价格排序方式（可选），可以传入 "asc" 表示按价格升序排序，或 "desc" 表示按价格降序排序
     * @param distanceOrder 距离排序方式（可选），可以传入 "asc" 表示按距离从近到远排序，或 "desc" 表示按距离从远到近排序，默认为从近到远排序
     * @return 包含附近服务的分页结果，按指定的排序和过滤条件返回
     */
    @ApiOperation(value = "获取附近服务", notes = "根据用户的地理位置获取附近的服务，可以按服务名称、价格进行过滤，并按距离和价格排序")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功获取服务列表"),
            @ApiResponse(code = 400, message = "请求参数错误"),
            @ApiResponse(code = 500, message = "服务器内部错误")
    })
    @GetMapping("/referralServices")
    public GlobalResponse<PersonalService> referralServices(
            @ApiParam(value = "分页信息封装对象", required = false)
            GlobalResponse<PersonalService> page,

            @ApiParam(value = "用户当前位置的经度", required = true)
            @RequestParam Double longitude,

            @ApiParam(value = "用户当前位置的纬度", required = true)
            @RequestParam Double latitude,

            @ApiParam(value = "服务名称（模糊查询）", required = false)
            @RequestParam(required = false) String serviceName,

            @ApiParam(value = "最低服务价格", required = false)
            @RequestParam(required = false) BigDecimal minPrice,

            @ApiParam(value = "最高服务价格", required = false)
            @RequestParam(required = false) BigDecimal maxPrice,

            @ApiParam(value = "价格排序方式（asc: 升序, desc: 降序）")
            @RequestParam(defaultValue = "asc") String priceOrder,

            @ApiParam(value = "距离排序方式（asc: 从近到远, desc: 从远到近）")
            @RequestParam(defaultValue = "asc") String distanceOrder
    ) {

        try {
            // 通过高德地图API获取地理位置详细信息
            var mapDetail = mapService.getReverseGeocoding(longitude, latitude);
            JSONObject addressComponent = mapDetail.getJSONObject("addressComponent");
            String province = addressComponent.getString("province");
            String city = addressComponent.getString("city");
            String district = addressComponent.getString("district");

            // 构建查询条件
            LambdaQueryWrapper<PersonalService> wrapper = new LambdaQueryWrapper<>();
            wrapper.eq(PersonalService::getProvince, province)
                    .eq(PersonalService::getCity, city)
                    .eq(PersonalService::getDistrict, district);

            // 根据服务名称过滤（如果提供）
            if (serviceName != null && !serviceName.trim().isEmpty()) {
                wrapper.like(PersonalService::getServiceName, serviceName);
            }

            // 根据服务价格过滤（如果提供）
            if (minPrice != null) {
                wrapper.ge(PersonalService::getPrice, minPrice);
            }
            if (maxPrice != null) {
                wrapper.le(PersonalService::getPrice, maxPrice);
            }

            // 构建距离计算公式
            String distanceCalculation = String.format(
                    "(6371 * acos(cos(radians(%s)) * cos(radians(latitude)) * cos(radians(longitude) - radians(%s)) + sin(radians(%s)) * sin(radians(latitude))))",
                    latitude, longitude, latitude
            );

            // 使用 .last() 手动插入排序的 SQL 语句
            StringBuilder orderByClause = new StringBuilder();
            if ("desc".equalsIgnoreCase(distanceOrder)) {
                orderByClause.append(distanceCalculation).append(" DESC");
            } else {
                orderByClause.append(distanceCalculation).append(" ASC");
            }

            // 添加价格排序（如果指定）
            if ("asc".equalsIgnoreCase(priceOrder)) {
                orderByClause.append(", price ASC");
            } else if ("desc".equalsIgnoreCase(priceOrder)) {
                orderByClause.append(", price DESC");
            }

            // 最后添加创建时间排序
            orderByClause.append(", create_time DESC");

            // 将最后的排序条件添加到查询中
            wrapper.last("ORDER BY " + orderByClause);

            // 返回分页查询结果
            return service.page(page, wrapper);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

    }


}
