package com.yskj.acdr.master.setting.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.util.StrUtil;
import com.yskj.acdr.common.cache.GlobalRedisCache;
import com.yskj.acdr.common.response.GlobalResponse;
import com.yskj.acdr.common.verify.UserNameValidator;
import com.yskj.acdr.master.setting.entity.AccountInfo;
import com.yskj.acdr.master.user.entity.Users;
import com.yskj.acdr.master.user.service.AuthenticationService;
import com.yskj.acdr.master.user.service.UsersService;
import jakarta.annotation.Resource;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

@RequestMapping("/setting")
@RestController
public class SettingController {

    @Resource
    private UsersService usersService;

    @Resource
    private AuthenticationService authService;

    @Resource
    private GlobalRedisCache<String> redisCache;

    @Resource
    private UserNameValidator userValid;

    /**
     * 获取账户信息
     * @return 账户信息类
     */
    @GetMapping("/info")
    public GlobalResponse<AccountInfo> info() {
        Users users = usersService.getById(StpUtil.getLoginIdAsLong());
        return GlobalResponse.success(
                new AccountInfo()
                        .setUserAvatar(users.getAvatar())
                        .setIsAuth(authService.isRealName())
                        .setPhone(users.getPhone())
                        .setUserName(users.getNickname())
        );
    }

    /**
     * 修改手机号
     */
    @PostMapping("/updatePhone")
    @Transactional
    public GlobalResponse<Boolean> updatePhone(String code,String newPhone) {
        // 验证验证码
        String cachedCode = redisCache.get(newPhone);
        if (cachedCode == null || !cachedCode.equals(code)) {
            return GlobalResponse.failure("验证码错误或已过期");
        }
        // 更新用户手机号
        Users users = usersService.getById(StpUtil.getLoginIdAsLong());
        users.setPhone(newPhone);
        return GlobalResponse.success(usersService.updateById(users));
    }

    /**
     * 修改用户名称
     */
    @PostMapping("/updateUserAvatar")
    @Transactional
    public GlobalResponse<Boolean> updateUserAvatar(String userAvatar) {
        Users users = usersService.getById(StpUtil.getLoginIdAsLong());
        users.setAvatar(userAvatar);
        return GlobalResponse.success(usersService.updateById(users));
    }

    /**
     * 修改用户头像
     */
    @PostMapping("/updateUserName")
    @Transactional
    public GlobalResponse<Boolean> updateUserName(String userName) {
        // 这里添加验证信息
        if (!userValid.valid(userName)) {
            return GlobalResponse.failure("用户名不合理,%s，请重新输入!".formatted(userValid.getErrorString()));
        }
        // 更新用户手机号
        Users users = usersService.getById(StpUtil.getLoginIdAsLong());
        users.setNickname(userName);
        return GlobalResponse.success(usersService.updateById(users));
    }

}
